Index: wp-includes/theme.php
===================================================================
--- wp-includes/theme.php	(revision 8753)
+++ wp-includes/theme.php	(working copy)
@@ -267,10 +267,10 @@
 		// Check for theme name collision.  This occurs if a theme is copied to
 		// a new theme directory and the theme header is not updated.  Whichever
 		// theme is first keeps the name.  Subsequent themes get a suffix applied.
 		// The Default and Classic themes always trump their pretenders.
 		if ( isset($themes[$name]) ) {
-			if ( ('WordPress Default' == $name || 'WordPress Classic' == $name) &&
-					 ('default' == $stylesheet || 'classic' == $stylesheet) ) {
+			if ( ('WordPress Default' == $name || 'WordPress Classic' == $name || 'Sandbox' == $name) &&
+					 ('default' == $stylesheet || 'classic' == $stylesheet || 'sandbox' == $stylesheet) ) {
 				// If another theme has claimed to be one of our default themes, move
 				// them aside.
 				$suffix = $themes[$name]['Stylesheet'];
@@ -267,10 +267,10 @@
 		// a new theme directory and the theme header is not updated.  Whichever
 		// theme is first keeps the name.  Subsequent themes get a suffix applied.
-		// The Default and Classic themes always trump their pretenders.
+		// The Default, Classic and Sandbox themes always trump their pretenders.
 		if ( isset($themes[$name]) ) {

Property changes on: wp-content/themes
___________________________________________________________________
Name: svn:externals
   + sandbox http://sandbox-theme.googlecode.com/svn/tags/1.6/


